**this file will be overwriten! **

 - Write documentation describing your app, files starting __ are ignored.

 - or add to `links.json`

## Settings

 - *activation*: <i>map_2d</i>

 - *run_state*: None

 - *progress*: None

 - *profile*: Run a profile on the run to find performance problems

 - *scan_mode*: 
<p><i>co-move:</i> all actuators co-move
<p><i>nested:</i> actuators move all combinations where 1st is slowest ...
<p><i>serpentine:</i> actuators move all combinations where 1st is slowest, 2nd is fastest and 2nd reverses direction every row.
<p><i>*_swap_order</i> modes are the same as above, but the order of the actuators is swapped.</p>


 - *collection_delay*: after setting the wheel position, data collection is delayed allowing system to reach steady state

 - *res_in_new_dir*: dumps data in a new sub folder. Intended for <i>any_measurement</i> where a file is stored per acquisition

 - *plot_option*: plot option

 - *any_measurement*: None

 - *any_setting*: None

 - *powermeter_monitoring_repetitions*: number of times data gets collected at each position

 - *blaze_repetitions*: number of times data gets collected at each position

 - *pylon_repetitions*: number of times data gets collected at each position

 - *coincidences_repetitions*: number of times data gets collected at each position

 - *thorcam_repetitions*: number of times data gets collected at each position

 - *any_measurement_repetitions*: number of times data gets collected at each position

 - *read_any_setting_repetitions*: number of times data gets collected at each position

 - *actuator_1*: None

 - *range_1_min*: 

 - *range_1_max*: 

 - *range_1_step*: 

 - *range_1_num*: 

 - *range_1_center*: 

 - *range_1_span*: 

 - *actuator_2*: None

 - *range_2_min*: 

 - *range_2_max*: 

 - *range_2_step*: 

 - *range_2_num*: 

 - *range_2_center*: 

 - *range_2_span*: 

